CREATE TABLE FISCALLOG
  (
    IDFISCALLOG NUMBER(*,0),
    ID_RACUN    NUMBER(*,0),
    TS TIMESTAMP (6),
    IDPORUKE    VARCHAR2(36 CHAR),
    ZASTITNIKOD VARCHAR2(32 CHAR),
    JIR         VARCHAR2(50 CHAR),
    ERRORCODE   VARCHAR2(4 CHAR),
    ERRORMSG    VARCHAR2(500 CHAR),
    STATUS      CHAR(1 CHAR),
    CONSTRAINT PK_FISCALLOG PRIMARY KEY (IDFISCALLOG)
  );

CREATE SEQUENCE FISCALLOG_PK_SEQ START WITH 1;

CREATE TABLE FISC_CONF(
ID_FISC_CONF NUMBER NOT NULL,
ALIAS VARCHAR2(250 CHAR) NOT NULL,
STOREPASS VARCHAR2(250 CHAR) NOT NULL,
KEYPASS VARCHAR2(250 CHAR) NOT NULL,
URL_GOVERNMENT VARCHAR2(250 CHAR) NOT NULL,
CERT_PATH VARCHAR2(250 CHAR),
CONSTRAINT PK_FISC_CONF PRIMARY KEY (ID_FISC_CONF)
);

INSERT INTO FISC_CONF (ID_FISC_CONF, ALIAS, STOREPASS, KEYPASS, URL_GOVERNMENT, CERT_PATH) VALUES (1, 'Alias', 'Username', 'password', 'https://', null);

CREATE TABLE FISC_RESEND (
  ID_SALDKONT NUMBER NOT NULL,
  datum_kreiranja date not null,
  user_kreiranja VARCHAR2(20 CHAR) NOT NULL,
  CONSTRAINT PK_FISC_RESEND 
);

DROP VIEW V_RACUN;

CREATE VIEW V_RACUN AS 
SELECT R.ID_SALDKONT AS ID_RACUN, SK.F_DAVCNA_STEVILKA AS OIB, 1 AS OBVEZATNIK, R.DATUM_KREIRANJA AS CAS, 'P' AS SLIJEDNOST, 
((R.N_KNJIZBE || '/REC/' || TO_CHAR(R.DATUM, 'YYYY'))) AS BROJ_RACUNA, 
R.N_KNJIZBE AS NBROJ_RACUNA, 'REC' AS POSLOVNI_PROSTOR, 1 AS NAPLATNI_UREDAJ, R.ZA_PLACILO AS IZNOS, 
(CASE PL.PLACIL WHEN 1 THEN (CASE NP.ID_CARDS WHEN 'GOD' THEN 'G' WHEN 'GOT' THEN 'G' WHEN 'KAR' THEN 'K' WHEN 'CEK' THEN 'C' ELSE 'O' END) ELSE 'O' END) AS NACIN_PLACANJA , 
R.GOVERMENT, R.GOVERMENT_CODE, R.PARAGON_ST AS PARAGON_RACUN
FROM SALDKONT R 
JOIN SALDKONT_KUPEC SK ON R.ID_SALDKONT=SK.ID_SALDKONT
LEFT OUTER JOIN EXCHANGE E ON R.ID_EXCHANGE=E.ID
LEFT OUTER JOIN (SELECT ID_MENJAVE, ID_CARDS FROM MONEY WHERE ROWNUM=1) NP ON E.ID=NP.ID_MENJAVE
LEFT OUTER JOIN (SELECT ID_MENJAVE, COUNT(*) AS PLACIL FROM MONEY GROUP BY ID_MENJAVE) PL ON E.ID=PL.ID_MENJAVE
WHERE R.VRSTA_RACUNA='RAC'
;

DROP VIEW V_RACUN_PNP;

CREATE VIEW V_RACUN_PNP AS
SELECT SA.ID_SALDKONT AS ID_RACUN, D.STOPNJA AS POREZ_STOPA, SUM(D.ZNESEK_OSNOVE) AS OSNOVICA, SUM(D.ZNESEK_DAVKA) AS POREZ_IZNOS 
FROM SALDKONT SA
JOIN RACUN_DATA R ON SA.ID_SALDKONT=R.ID_SALDKONT
JOIN M_STORITVE S ON R.ID_STORITVE=S.ID_STORITVE
JOIN M_STORITVE_DAVEK D ON S.ID_STORITVE=D.ID_STORITVE 
WHERE D.VRSTA='PNP'
GROUP BY SA.ID_SALDKONT, D.STOPNJA
;

DROP VIEW V_RACUN_PDV;

CREATE VIEW V_RACUN_PDV AS
SELECT ID_RACUN, POREZ_STOPA, SUM(OSNOVICA) AS OSNOVICA, SUM(POREZ_IZNOS) AS POREZ_IZNOS FROM
(SELECT R.ID_SALDKONT AS ID_RACUN, D.STOPNJA AS POREZ_STOPA, SUM(D.ZNESEK_OSNOVE) AS OSNOVICA, SUM(D.ZNESEK_DAVKA) AS POREZ_IZNOS 
FROM RACUN_DATA R
LEFT OUTER JOIN M_STORITVE_DAVEK D ON R.ID_STORITVE=D.ID_STORITVE  AND D.VRSTA='DDV'
WHERE D.ID_STORITVE IS NOT NULL
GROUP BY R.ID_SALDKONT, D.STOPNJA
union
SELECT R.ID_SALDKONT AS ID_RACUN, R.DAV_STOPNJA AS POREZ_STOPA, SUM(R.NETO) AS OSNOVICA, SUM(R.ZN_DAVKA) AS POREZ_IZNOS 
FROM RACUN_DATA R
LEFT OUTER JOIN M_STORITVE_DAVEK D ON R.ID_STORITVE=D.ID_STORITVE 
WHERE D.ID_STORITVE IS NULL
GROUP BY R.ID_SALDKONT, R.DAV_STOPNJA) DDV
GROUP BY ID_RACUN, POREZ_STOPA
;

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (258, SYSDATE, '5.5', 178, 'fiskalizacija');